=============
User Guide
=============

Dataset
========
.. toctree::
   :maxdepth: 4

   datasets.rst

Common Usage Examples
======================
.. toctree::
   :maxdepth: 4

   basic_usage

Kernel-based quadratic distance (KBQD) Goodness-of-Fit tests
=============================================================
.. toctree::
   :maxdepth: 4

   kbqd.rst

Select the value of the kernel tuning parameter (h)
====================================================
.. toctree::
   :maxdepth: 4

   hselect.rst

Random Sampling from PKBD
===========================
.. toctree::
   :maxdepth: 4

   pkbd.rst
   gen_plot_rpkb

Poisson kernel-based quadratic distance test of Uniformity on the sphere
=========================================================================
.. toctree::
   :maxdepth: 4

   pktest.rst

Usage Instructions for Dashboard Application
==============================================
.. toctree::
   :maxdepth: 4

   dashboard_application_usage